@@ -7,7 +7,7 @@
 #include <sys/un.h>
 #include <sys/wait.h>
 #include <unistd.h>
-#include <sysdeps.h>
+#include "haswaitp.h"
 
 extern void setup_env(int, const char*);
 
@@ -33,7 +33,7 @@ static uid_t opt_socket_uid = -1;
 static gid_t opt_socket_gid = -1;
 static mode_t opt_perms = 0;
 static mode_t opt_umask = 0;
-static int opt_backlog = 128;
+static unsigned int opt_backlog = 128;
 static const char* opt_banner = 0;
 
 void usage(const char* message)
@@ -205,8 +205,13 @@ int make_socket()
 
 void start_child(int fd)
 {
-  if(opt_banner)
-    write(fd, opt_banner, strlen(opt_banner));
+  if(opt_banner) {
+    ssize_t len = strlen(opt_banner);
+    if(write(fd, opt_banner, len) != len) {
+      perror("write");
+      exit(-1);
+    }
+  }
   setup_env(fd, opt_socket);
   close(0);
   close(1);
